export interface Logger {
    info?(...any: any[]): any;
    error?(...any: any[]): any;
    debug?(...any: any[]): any;
}
export interface Cache {
    get<T>(key: string): T;
    set<T>(key: string, payload: T): void;
}
export interface IHttpClient {
    get<T>(route: string): Promise<T>;
    post<T>(route: string, payload?: object): Promise<T>;
    patch<T>(route: string, payload?: object): Promise<T>;
    put<T>(route: string, payload: object): Promise<T>;
    delete(route: string): any;
}
export declare class HttpClient implements IHttpClient {
    private _baseUrl;
    private _logger;
    private _defaultHeaders;
    constructor(baseUrl: string, logger?: Logger, basicAuthUser?: string, basicAuthPwd?: string, bearer?: string, defaultHeaders?: object);
    private _request;
    get<T>(route: string): Promise<T>;
    post<T>(route: string, payload?: object): Promise<T>;
    patch<T>(route: string, payload?: object): Promise<T>;
    put<T>(route: string, payload: object): Promise<T>;
    delete(route: string): Promise<any>;
}
export declare class RequestException extends Error {
    statusCode: any;
    innerError: any;
    constructor(message: any, statusCode: any, inner: any);
}
export declare class TestHttpClient implements IHttpClient {
    _routePayloads: any;
    calls: any;
    constructor(routePayloads: any);
    get(route: any): Promise<any>;
    post(route: any, payload: any): Promise<any>;
    put(route: any, payload: any): Promise<any>;
    patch(route: any, payload: any): Promise<any>;
    delete(route: any): Promise<any>;
}
export declare class CachedClient implements IHttpClient {
    private _httpClient;
    private _logger;
    private _cache;
    constructor(httpClient: HttpClient, logger: Logger, cache: Cache);
    get<T>(route: string): Promise<T>;
    post<T>(route: string, payload?: object): Promise<T>;
    put<T>(route: string, payload?: object): Promise<T>;
    patch<T>(route: string, payload?: object): Promise<T>;
    delete(route: string): Promise<void>;
}
